[telepathy-glib/master] account{, -manager}: renamed _is_ready to _is_prepared

Jonny Lamb jonny.lamb at collabora.co.uk
Sat Sep 26 04:18:54 PDT 2009


Signed-off-by: Jonny Lamb <jonny.lamb at collabora.co.uk>
---
 docs/reference/telepathy-glib-sections.txt |    4 ++--
 telepathy-glib/account-manager.c           |   12 ++++++------
 telepathy-glib/account-manager.h           |    2 +-
 telepathy-glib/account.c                   |    8 ++++----
 telepathy-glib/account.h                   |    2 +-
 5 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/docs/reference/telepathy-glib-sections.txt b/docs/reference/telepathy-glib-sections.txt
index 12aafa2..3612d8f 100644
--- a/docs/reference/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib-sections.txt
@@ -3026,7 +3026,7 @@ tp_account_get_avatar_async
 tp_account_get_avatar_finish
 <SUBSECTION>
 TP_ACCOUNT_FEATURE_CORE
-tp_account_is_ready
+tp_account_is_prepared
 tp_account_prepare_async
 tp_account_prepare_finish
 tp_account_get_requested_features
@@ -3077,7 +3077,7 @@ tp_account_manager_get_most_available_presence
 tp_account_manager_set_all_requested_presences
 <SUBSECTION>
 TP_ACCOUNT_MANAGER_FEATURE_CORE
-tp_account_manager_is_ready
+tp_account_manager_is_prepared
 tp_account_manager_prepare_async
 tp_account_manager_prepare_finish
 tp_account_manager_get_requested_features
diff --git a/telepathy-glib/account-manager.h b/telepathy-glib/account-manager.h
index 090ff39..f5dac11 100644
--- a/telepathy-glib/account-manager.h
+++ b/telepathy-glib/account-manager.h
@@ -94,7 +94,7 @@ void tp_account_manager_create_account_async (TpAccountManager *manager,
 TpAccount * tp_account_manager_create_account_finish (
     TpAccountManager *manager, GAsyncResult *result, GError **error);
 
-gboolean tp_account_manager_is_ready (TpAccountManager *manager,
+gboolean tp_account_manager_is_prepared (TpAccountManager *manager,
     GQuark feature);
 
 void tp_account_manager_prepare_async (TpAccountManager *manager,
diff --git a/telepathy-glib/account.h b/telepathy-glib/account.h
index 7ae9a2f..1dbf436 100644
--- a/telepathy-glib/account.h
+++ b/telepathy-glib/account.h
@@ -178,7 +178,7 @@ void tp_account_get_avatar_async (TpAccount *account,
 const GArray *tp_account_get_avatar_finish (TpAccount *account,
     GAsyncResult *result, GError **error);
 
-gboolean tp_account_is_ready (TpAccount *account, GQuark feature);
+gboolean tp_account_is_prepared (TpAccount *account, GQuark feature);
 
 void tp_account_prepare_async (TpAccount *account, const GQuark *features,
     GAsyncReadyCallback callback, gpointer user_data);
diff --git a/telepathy-glib/account-manager.c b/telepathy-glib/account-manager.c
index a462f85..3babc66 100644
--- a/telepathy-glib/account-manager.c
+++ b/telepathy-glib/account-manager.c
@@ -203,7 +203,7 @@ _tp_account_manager_check_features (TpAccountManager *self,
       feat = _tp_account_manager_get_feature (self, *f);
 
       /* features which are NULL (ie. don't exist) are always considered as
        * being ready, except in _is_ready when it doesn't make sense to
        * return TRUE. */
       if (feat != NULL && !feat->ready)
         return FALSE;
@@ -393,7 +393,7 @@ _tp_account_manager_check_core_ready (TpAccountManager *manager)
   GHashTableIter iter;
   gpointer value;
 
-  if (tp_account_manager_is_ready (manager, TP_ACCOUNT_MANAGER_FEATURE_CORE))
+  if (tp_account_manager_is_prepared (manager, TP_ACCOUNT_MANAGER_FEATURE_CORE))
     return;
 
   g_hash_table_iter_init (&iter, priv->accounts);
@@ -401,7 +401,7 @@ _tp_account_manager_check_core_ready (TpAccountManager *manager)
     {
       TpAccount *account = TP_ACCOUNT (value);
 
-      if (!tp_account_is_ready (account, TP_ACCOUNT_FEATURE_CORE))
+      if (!tp_account_is_prepared (account, TP_ACCOUNT_FEATURE_CORE))
         return;
     }
 
@@ -1070,7 +1070,7 @@ tp_account_manager_set_all_requested_presences (TpAccountManager *manager,
     {
       TpAccount *account = TP_ACCOUNT (value);
 
-      if (tp_account_is_ready (account, TP_ACCOUNT_FEATURE_CORE))
+      if (tp_account_is_prepared (account, TP_ACCOUNT_FEATURE_CORE))
         tp_account_request_presence_async (account, type, status, message,
             NULL, NULL);
     }
@@ -1257,7 +1257,7 @@ tp_account_manager_create_account_finish (TpAccountManager *manager,
 }
 
 /**
- * tp_account_manager_is_ready:
+ * tp_account_manager_is_prepared:
  * @manager: a #TpAccountManager
  * @feature: a feature which is required
  * @error: a #GError to fill
@@ -1269,7 +1269,7 @@ tp_account_manager_create_account_finish (TpAccountManager *manager,
  * Since: 0.7.UNRELEASED
  */
 gboolean
-tp_account_manager_is_ready (TpAccountManager *manager,
+tp_account_manager_is_prepared (TpAccountManager *manager,
     GQuark feature)
 {
   TpAccountManagerFeature *f;
@@ -203,7 +203,7 @@ _tp_account_manager_check_features (TpAccountManager *self,
 
       /* features which are NULL (ie. don't exist) are always considered as
-       * being ready, except in _is_ready when it doesn't make sense to
+       * being ready, except in _is_prepared when it doesn't make sense to
        * return TRUE. */
       if (feat != NULL && !feat->ready)
diff --git a/telepathy-glib/account.c b/telepathy-glib/account.c
index 099b17a..f043681 100644
--- a/telepathy-glib/account.c
+++ b/telepathy-glib/account.c
@@ -260,7 +260,7 @@ _tp_account_check_features (TpAccount *self,
       feat = _tp_account_get_feature (self, *f);
 
       /* features which are NULL (ie. don't exist) are always considered as
        * being ready, except in _is_ready when it doesn't make sense to
        * return TRUE. */
       if (feat != NULL && !feat->ready)
         return FALSE;
@@ -662,7 +662,7 @@ _tp_account_properties_changed (TpAccount *proxy,
 {
   TpAccount *self = TP_ACCOUNT (weak_object);
 
-  if (!tp_account_is_ready (self, TP_ACCOUNT_FEATURE_CORE))
+  if (!tp_account_is_prepared (self, TP_ACCOUNT_FEATURE_CORE))
     return;
 
   _tp_account_update (self, properties);
@@ -2577,7 +2577,7 @@ tp_account_get_avatar_finish (TpAccount *account,
 }
 
 /**
- * tp_account_is_ready:
+ * tp_account_is_prepared:
  * @account: a #TpAccount
  * @feature: a feature which is required
  *
@@ -2588,7 +2588,7 @@ tp_account_get_avatar_finish (TpAccount *account,
  * Since: 0.7.UNRELEASED
  */
 gboolean
-tp_account_is_ready (TpAccount *account,
+tp_account_is_prepared (TpAccount *account,
     GQuark feature)
 {
   TpAccountFeature *f;
@@ -260,7 +260,7 @@ _tp_account_check_features (TpAccount *self,
 
       /* features which are NULL (ie. don't exist) are always considered as
-       * being ready, except in _is_ready when it doesn't make sense to
+       * being ready, except in _is_prepared when it doesn't make sense to
        * return TRUE. */
       if (feat != NULL && !feat->ready)
-- 
1.5.6.5




More information about the telepathy-commits mailing list